@@ -40,8 +40,11 @@
 #' The confidence interval for the proportional distance is computed via bootstrapping (percentile bootstrap).
 #'
 #' @examples
-#' d<-perfectionism
-#' neg.intcont(outcome = mpshfpre.sop, pred1 = cesdpre.total, pred2 = atqpre.total, data = d,
+#' y<-rnorm(25)
+#' x1<-rnorm(25)
+#' x2<-rnorm(25)
+#' d<-data.frame(y,x1,x2)
+#' neg.intcont(outcome = y, pred1 = x1, pred2 = x2, data = d,
 #' eiL = -.25, eiU = .25, standardized = TRUE, nbootpd = 100)
 neg.intcont <- function (outcome = NULL, pred1 = NULL,
                          pred2 = NULL, eiL, eiU, standardized = TRUE,
@@ -59,19 +62,26 @@ neg.intcont <- function (outcome = NULL, pred1 = NULL,
     dat<-data.frame(outcome, pred1, pred2)
     dat<-dat[stats::complete.cases(dat),]
     mod <- stats::lm(outcome ~ pred1*pred2, data=dat)
-    invisible(utils::capture.output(sprs<-rockchalk::getDeltaRsquare(mod)))
+    invisible(utils::capture.output(sprs<-
+          rockchalk::getDeltaRsquare(mod)))
+    sprs<-round(sprs,3)
     cis <- stats::confint(mod, level = 1-2*alpha)
     intcil <- cis["pred1:pred2",1]
+    intcil <- round(intcil, 3)
     intciu <- cis["pred1:pred2",2]
+    intciu <- round(intciu, 3)
     cisr <- stats::confint(mod, level = 1-alpha)
     intcilr <- cisr["pred1:pred2",1]
+    intcilr <- round(intcilr, 3)
     intciur <- cisr["pred1:pred2",2]
+    intciur <- round(intciur, 3)
     intcoef <- stats::coef(mod)["pred1:pred2"]
+    intcoef <- round(intcoef, 3)
     ifelse(intcil >= eiL & intciu <= eiU,
            decis <- "The null hypothesis that the interaction is not negligible can be rejected",
            decis <- "The null hypothesis that the interaction is not negligible CANNOT be rejected")
     test<-"Standard TOST method is used since standardized = FALSE"
-    
+
     # Calculate Proportional Distance
     ifelse(intcoef<0, eiPD<-eiL, eiPD<-eiU)
     PD <- intcoef/abs(eiPD)
@@ -95,29 +105,37 @@ neg.intcont <- function (outcome = NULL, pred1 = NULL,
     dat <- data.frame(outcome,pred1,pred2,int)
     dat <- dat[stats::complete.cases(dat),]
     m <- stats::lm(outcome ~ pred1*pred2, data=dat)
-    invisible(utils::capture.output(sprs <- rockchalk::getDeltaRsquare(m)))
-    invisible(utils::capture.output(SEs<-fungible::seBeta(X = dat[,2:4], y = dat[,1],
-                                                          cov.x = stats::cov(dat[,2:4]),
-                                                          cov.xy = stats::cov(dat[,1:4])[1,2:4],
-                                                          var.y = stats::var(dat[,1]),
-                                                          Nobs = nrow(dat),
-                                                          alpha = alpha*2)))
+    invisible(utils::capture.output(sprs <-
+          rockchalk::getDeltaRsquare(m)))
+    sprs<-round(sprs,3)
+    invisible(utils::capture.output(SEs<-
+          fungible::seBeta(X = dat[,2:4], y = dat[,1],
+          cov.x = stats::cov(dat[,2:4]),
+          cov.xy = stats::cov(dat[,1:4])[1,2:4],
+          var.y = stats::var(dat[,1]),
+          Nobs = nrow(dat),
+          alpha = alpha*2)))
     intcil<-SEs$CIs[3,1]
+    intcil <- round(intcil, 3)
     intciu<-SEs$CIs[3,3]
+    intciu <- round(intciu, 3)
     intcoef<-SEs$CIs[3,2]
+    intcoef <- round(intcoef, 3)
     ifelse(intcil >= eiL & intciu <= eiU,
            decis <- "The null hypothesis that the interaction is not negligible can be rejected",
            decis <- "The null hypothesis that the interaction is not negligible CANNOT be rejected")
     invisible(utils::capture.output(SEsr<-fungible::seBeta(X = dat[,2:4], y = dat[,1],
-                                                           cov.x = stats::cov(dat[,2:4]),
-                                                           cov.xy = stats::cov(dat[,1:4])[1,2:4],
-                                                           var.y = stats::var(dat[,1]),
-                                                           Nobs = nrow(dat),
-                                                           alpha = alpha)))
+          cov.x = stats::cov(dat[,2:4]),
+          cov.xy = stats::cov(dat[,1:4])[1,2:4],
+          var.y = stats::var(dat[,1]),
+          Nobs = nrow(dat),
+          alpha = alpha)))
     intcilr<-SEsr$CIs[3,1]
+    intcilr <- round(intcilr, 3)
     intciur<-SEsr$CIs[3,3]
+    intciur <- round(intciur, 3)
     test<-"-- The Delta Method is used for Calculating the SEs with Standardized Variables --"
-    
+
     # Calculate Proportional Distance
     ifelse(intcoef<0, eiPD<-eiL, eiPD<-eiU)
     PD <- intcoef/abs(eiPD)
@@ -174,11 +192,9 @@ print.neg.intcont <- function(x, ...) {
   cat("Upper Bound of the Negligible Effect (Equivalence) Interval: ", "\n", x$eiU, "\n\n")
   cat("NHST Decision: ", "\n", x$decis, "\n\n")
   cat("**********************\n\n")
-  
+
   if (x$pl == TRUE) {
     neg.pd(effect=x$intcoef, PD = x$PD, eil = x$eiL, eiu = x$eiU, PDcil=x$CI95L, PDciu=x$CI95U, cil=x$intcil, ciu=x$intciu, Elevel=100*(1-2*x$alpha), Plevel=100*(1-x$alpha), save = x$save, oe=x$oe)
   }
 }
 
-
-
